@@ -1473,6 +1473,9 @@ static PyObject *ra_get_dir(PyObject *self, PyObject *args)
 	if (revision != SVN_INVALID_REVNUM)
 		fetch_rev = revision;
 
+	/* Yuck. Subversion doesn't like leading slashes.. */
+	while (*path == '/') path++;
+
 	RUN_RA_WITH_POOL(temp_pool, ra, svn_ra_get_dir2(ra->ra, &dirents, &fetch_rev, &props,
 					 svn_path_canonicalize(path, temp_pool), revision, dirent_fields, temp_pool));
 
@@ -1528,6 +1531,9 @@ static PyObject *ra_get_file(PyObject *self, PyObject *args)
 	if (revision != SVN_INVALID_REVNUM)
 		fetch_rev = revision;
 
+	/* Yuck. Subversion doesn't like leading slashes.. */
+	while (*path == '/') path++;
+
 	RUN_RA_WITH_POOL(temp_pool, ra, svn_ra_get_file(ra->ra, svn_path_canonicalize(path, temp_pool), revision, 
 													new_py_stream(temp_pool, py_stream), 
 													&fetch_rev, &props, temp_pool));
@@ -3031,6 +3037,9 @@ void init_ra(void)
 	PyModule_AddObject(mod, "Auth", (PyObject *)&Auth_Type);
 	Py_INCREF(&Auth_Type);
 
+	PyModule_AddObject(mod, "Editor", (PyObject *)&Editor_Type);
+	Py_INCREF(&Editor_Type);
+
 	busy_exc = PyErr_NewException("_ra.BusyException", NULL, NULL);
 	PyModule_AddObject(mod, "BusyException", busy_exc);
 
