@@ -3,16 +3,16 @@
  * -*- coding: utf-8 -*-
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
@@ -98,6 +98,7 @@ static PyObject *wrap_py_commit_items(const apr_array_header_t *commit_items)
 			}
 		} else {
 			copyfrom = Py_None;
+			Py_INCREF(copyfrom);
 		}
 
 		item = Py_BuildValue("(szlNi)", 
@@ -311,20 +312,39 @@ static PyObject *client_add(PyObject *self, PyObject *args, PyObject *kwargs)
 	char *path; 
 	ClientObject *client = (ClientObject *)self;
 	bool recursive=true, force=false, no_ignore=false;
+	bool add_parents = true;
 	apr_pool_t *temp_pool;
-	char *kwnames[] = { "path", "recursive", "force", "no_ignore", NULL };
+	char *kwnames[] = { "path", "recursive", "force", "no_ignore", 
+						"add_parents", NULL };
 
-	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s|bbb", kwnames, 
-						  &path, &recursive, &force, &no_ignore))
+	if (!PyArg_ParseTupleAndKeywords(args, kwargs, "s|bbbb", kwnames, 
+						  &path, &recursive, &force, &no_ignore, &add_parents))
 		return NULL;
+
+#if SVN_VER_MAJOR <= 1 && SVN_VER_MINOR < 4
+	if (add_parents == false) {
+		PyErr_SetString(PyExc_NotImplementedError, 
+			"Subversion < 1.4 does not support add_parents=false");
+		return NULL;
+	}
+#endif
 	
 	temp_pool = Pool(NULL);
 	if (temp_pool == NULL)
 		return NULL;
 
+#if SVN_VER_MAJOR < 2 && SVN_VER_MINOR == 4
 	RUN_SVN_WITH_POOL(temp_pool, 
-					  svn_client_add3(path, recursive, force, no_ignore, 
-				client->client, temp_pool));
+		svn_client_add3(path, recursive, force, no_ignore, client->client, 
+						temp_pool)
+		);
+#else
+	RUN_SVN_WITH_POOL(temp_pool, 
+		svn_client_add4(path, recursive?svn_depth_infinity:svn_depth_empty, 
+						force, no_ignore, add_parents, 
+						client->client, temp_pool)
+		);
+#endif
 	apr_pool_destroy(temp_pool);
 	Py_RETURN_NONE;
 }
@@ -389,14 +409,14 @@ static PyObject *client_commit(PyObject *self, PyObject *args, PyObject *kwargs)
 static PyObject *client_delete(PyObject *self, PyObject *args)
 {
 	PyObject *paths; 
-	bool force=false;
+	bool force=false, keep_local=false;
 	apr_pool_t *temp_pool;
 	svn_commit_info_t *commit_info = NULL;
 	PyObject *ret;
 	apr_array_header_t *apr_paths;
 	ClientObject *client = (ClientObject *)self;
 
-	if (!PyArg_ParseTuple(args, "O|b", &paths, &force))
+	if (!PyArg_ParseTuple(args, "O|bb", &paths, &force, &keep_local))
 		return NULL;
 
 	temp_pool = Pool(NULL);
@@ -407,9 +427,21 @@ static PyObject *client_delete(PyObject *self, PyObject *args)
 		return NULL;
 	}
 
+#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 5
+	RUN_SVN_WITH_POOL(temp_pool, svn_client_delete3(&commit_info, 
+													apr_paths,
+				force, keep_local, NULL, client->client, temp_pool));
+#else
+	if (keep_local) {
+		PyErr_SetString(PyExc_ValueError, 
+						"keep_local not supported against svn 1.4");
+		apr_pool_destroy(temp_pool);
+		return NULL;
+	}
 	RUN_SVN_WITH_POOL(temp_pool, svn_client_delete2(&commit_info, 
 													apr_paths,
 				force, client->client, temp_pool));
+#endif
 
 	ret = py_commit_info_tuple(commit_info);
 
@@ -421,7 +453,7 @@ static PyObject *client_delete(PyObject *self, PyObject *args)
 static PyObject *client_copy(PyObject *self, PyObject *args)
 {
 	char *src_path, *dst_path;
-	PyObject *src_rev=Py_None;
+	PyObject *src_rev = Py_None;
 	svn_commit_info_t *commit_info = NULL;
 	apr_pool_t *temp_pool;
 	svn_opt_revision_t c_src_rev;
@@ -494,6 +526,34 @@ static PyObject *client_propget(PyObject *self, PyObject *args)
 	return ret;
 }
 
+static PyObject *client_resolve(PyObject *self, PyObject *args)
+{
+#if SVN_VER_MAJOR >= 1 && SVN_VER_MINOR >= 5
+	svn_depth_t depth;
+	svn_wc_conflict_choice_t choice;
+	ClientObject *client = (ClientObject *)self;
+	apr_pool_t *temp_pool;
+	char *path;
+	
+	if (!PyArg_ParseTuple(args, "sii", &path, &depth, &choice))
+		return NULL;
+
+	temp_pool = Pool(NULL);
+	if (temp_pool == NULL)
+		return NULL;
+	RUN_SVN_WITH_POOL(temp_pool, svn_client_resolve(path, depth, choice,
+			client->client, temp_pool));
+
+	apr_pool_destroy(temp_pool);
+
+	Py_RETURN_NONE;
+#else
+	PyErr_SetString(PyExc_NotImplementedError, 
+		"svn_client_resolve not available with Subversion < 1.5");
+	return NULL;
+#endif
+}
+
 static PyObject *client_update(PyObject *self, PyObject *args)
 {
 	bool recurse = true;
@@ -544,6 +604,7 @@ static PyMethodDef client_methods[] = {
 	{ "copy", client_copy, METH_VARARGS, "S.copy(src_path, dest_path, srv_rev=None)" },
 	{ "propset", client_propset, METH_VARARGS, "S.propset(name, value, target, recurse=True, skip_checks=False)" },
 	{ "propget", client_propget, METH_VARARGS, "S.propget(name, target, peg_revision, revision=None, recurse=False) -> value" },
+	{ "resolve", client_resolve, METH_VARARGS, "S.resolve(path, depth, choice)" },
 	{ "update", client_update, METH_VARARGS, "S.update(path, rev=None, recurse=True, ignore_externals=False) -> list of revnums" },
 	{ NULL, }
 };
@@ -597,7 +658,9 @@ static PyObject *config_get_dict(PyObject *self, void *closure)
 		apr_hash_this(idx, (const void **)&key, &klen, (void **)&val);
 		data = PyObject_New(ConfigItemObject, &ConfigItem_Type);
 		data->item = val;
+		data->parent = NULL;
 		PyDict_SetItemString(ret, key, (PyObject *)data);
+		Py_DECREF(data);
 	}
 
 	return ret;
