@@ -1,16 +1,16 @@
 # Copyright (C) 2006-2008 Jelmer Vernooij <jelmer@samba.org>
 
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation; either version 2.1 of the License, or
 # (at your option) any later version.
 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Lesser General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 """Python bindings for Subversion."""
@@ -50,6 +50,9 @@ class SSHSubprocess(object):
         self.proc.stdout.close()
         self.proc.wait()
 
+    def get_filelike_channels(self):
+        return (self.proc.stdout, self.proc.stdin)
+
 
 class SSHVendor(object):
 
@@ -70,27 +73,6 @@ class SSHVendor(object):
 get_ssh_vendor = SSHVendor
 
 
-class SSHSubprocess(object):
-    """A socket-like object that talks to an ssh subprocess via pipes."""
-
-    def __init__(self, proc):
-        self.proc = proc
-
-    def send(self, data):
-        return os.write(self.proc.stdin.fileno(), data)
-
-    def recv(self, count):
-        return os.read(self.proc.stdout.fileno(), count)
-
-    def close(self):
-        self.proc.stdin.close()
-        self.proc.stdout.close()
-        self.proc.wait()
-
-    def get_filelike_channels(self):
-        return (self.proc.stdout, self.proc.stdin)
-
-
 class SVNConnection(object):
 
     def __init__(self, recv_fn, send_fn):
@@ -1003,7 +985,14 @@ class SVNServer(SVNConnection):
 
     def serve(self):
         self.send_greeting()
-        (version, capabilities, url) = self.recv_msg()
+        msg = self.recv_msg()
+        version = msg[0]
+        capabilities = msg[1]
+        url = msg[2]
+        if len(msg) > 3:
+            self.client_user_agent = msg[3]
+        else:
+            self.client_user_agent = None
         self.capabilities = capabilities
         self.version = version
         self.url = url
