@@ -1,24 +1,29 @@
 # Copyright (C) 2005-2007 Jelmer Vernooij <jelmer@samba.org>
  
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# it under the terms of the GNU Lesser General Public License as published by
+# the Free Software Foundation; either version 2.1 of the License, or
 # (at your option) any later version.
 
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# GNU Lesser General Public License for more details.
 
-# You should have received a copy of the GNU General Public License
+# You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 """Subversion client library tests."""
 
-from subvertpy import client
-from subvertpy.tests import SubversionTestCase
+from subvertpy import (
+    client,
+    )
+from subvertpy.tests import (
+    SubversionTestCase,
+    )
 
 class TestClient(SubversionTestCase):
+
     def setUp(self):
         super(TestClient, self).setUp()
         self.repos_url = self.make_client("d", "dc")
